@@ -17,7 +17,7 @@ using namespace apolloron;
 
 const char *INKF_PROGNAME = "inkf";
 const char *INKF_BRIEF    = "Yet Another Network Kanji Filter";
-const char *INKF_VERSION  = "2.0.0";
+const char *INKF_VERSION  = "2.0.1";
 const char *INKF_COPY     = "Copyright (C) 2002-2018 Masashi Astro Tachibana";
 const char *INKF_DEF_OUT  = "inkf.out";
 
@@ -121,9 +121,13 @@ int main(int argc, char *argv[]) {
                 !option.flag_guess && !option.flag_html_to_plain && !option.flag_midi &&
                 strcasecmp(option.output_charset, "UTF-8_BOM") != 0 &&
                 strncasecmp(option.input_charset, "UTF-16", 6) != 0 &&
+                strncasecmp(option.input_charset, "UTF16", 5) != 0 &&
                 strncasecmp(option.input_charset, "UTF-32", 6) != 0 &&
-                !(!strcasecmp(option.output_charset, "UTF-16") ||
-                !strcasecmp(option.output_charset, "UTF-32"))) {
+                strncasecmp(option.input_charset, "UTF32", 5) != 0 &&
+                !(!strncasecmp(option.output_charset, "UTF-16", 6) ||
+                !strncasecmp(option.output_charset, "UTF16", 5) ||
+                !strncasecmp(option.output_charset, "UTF-32", 6) ||
+                !strncasecmp(option.output_charset, "UTF32", 5))) {
             while (!feof(fpin)) {
                 tmp_str = "";
                 while (!feof(fpin)) {
@@ -559,8 +563,9 @@ void guess(const String &str, const char *input_charset, FILE *fpout) {
         charcode = input_charset;
     }
 
-    if ((!strncmp(charcode, "UTF-16", 6) || !strncmp(charcode, "UTF-32", 6)) &&
-            strstr(charcode, "BE") != NULL) {
+    if ((!strncasecmp(charcode, "UTF-16", 6) || !strncasecmp(charcode, "UTF16", 5) ||
+            !strncasecmp(charcode, "UTF-32", 6) || !strncasecmp(charcode, "UTF32", 5)) &&
+            strcasestr(charcode, "BE") != NULL) {
         endian = 'B';
     } else {
         endian = 'L';
