@@ -87,7 +87,7 @@ FCGI::FCGI(FCGX_Request *request) {
     }
 
     if (0 < str.binaryLength()) {
-        int i, j, k, len;
+        long i, j, k, l, len;
         len = str.binaryLength();
         cpstr = getenv("CONTENT_TYPE");
         if (cpstr != NULL && !strncasecmp(cpstr, "multipart/form-data", 19)) {
@@ -101,8 +101,9 @@ FCGI::FCGI(FCGX_Request *request) {
 
             cpstr = strstr(cpstr, "boundary=");
             if (cpstr != NULL) {
-                boundary = new char [strlen(cpstr + strlen("boundary=")) + 3];
-                sprintf(boundary, "--%s", cpstr + strlen("boundary="));
+                l = strlen(cpstr + strlen("boundary=")) + 3;
+                boundary = new char [l];
+                ::snprintf(boundary, l, "--%s", cpstr + strlen("boundary="));
                 pstr = strchr(boundary, ';');
                 if (pstr != NULL) {
                     *pstr = '\0';
