@@ -18,7 +18,6 @@ namespace apolloron {
     @return void
  */
 IMAPMail::IMAPMail(IMAPStream *imap_stream, const String &mailbox, long uid) {
-    memset(&((*this).mailData), 0, sizeof(TMail));
     (*this).clear();
 
     (*this).imapStream = imap_stream;
@@ -50,17 +49,29 @@ bool IMAPMail::clear() {
 
     if ((*this).mailData.internalDate) {
         delete [] (*this).mailData.internalDate;
+        (*this).mailData.internalDate = (char *)NULL;
     }
     (*this).mailData.size = 0L;
     if ((*this).mailData.headerDate) {
         delete [] (*this).mailData.headerDate;
+        (*this).mailData.headerDate = (char *)NULL;
     }
     if ((*this).mailData.messageID) {
         delete [] (*this).mailData.messageID;
+        (*this).mailData.messageID = (char *)NULL;
     }
     if ((*this).mailData.subject) {
         delete [] (*this).mailData.subject;
+        (*this).mailData.subject = (char *)NULL;
     }
+    (*this).mailData.fromList.clear();
+    (*this).mailData.senderList.clear();
+    (*this).mailData.toList.clear();
+    (*this).mailData.ccList.clear();
+    (*this).mailData.bccList.clear();
+    (*this).mailData.replyToList.clear();
+    (*this).mailData.referenceList.clear();
+    (*this).mailData.flagList.clear();
     if ((*this).mailData.parts != NULL) {
         for (i = 0; i < (*this).mailData.partsLength; i++) {
             if ((*this).mailData.parts[i].id) {
@@ -80,8 +91,9 @@ bool IMAPMail::clear() {
             }
         }
         delete [] (*this).mailData.parts;
+        (*this).mailData.parts = (TMailPart *)NULL;
     }
-    memset(&((*this).mailData), 0, sizeof(TMail));
+    (*this).mailData.partsLength = 0L;
 
     (*this).AttachFilePartIDList.clear();
     (*this).tmpString.clear();
