@@ -505,7 +505,8 @@ String& Socket::receive(long size) {
     char *buf;
     long numrcv;
 
-    *((*this).tmpString) = "";
+    total = 0;
+    (*((*this).tmpString)).useAsBinary(total);
 
     if ((*this).bConnected == false || (*this).dstSocket < 0 || size < 0) {
         (*this).nErrno = -1;
@@ -517,9 +518,7 @@ String& Socket::receive(long size) {
         return *((*this).tmpString);
     }
 
-    total = 0;
     (*((*this).tmpString)).setFixedLength(size);
-    (*((*this).tmpString)).useAsBinary(total);
 
 #if __OPENSSL == 1
     if ((*this).bSSLStream) {
@@ -599,8 +598,7 @@ String& Socket::receiveLine() {
     char tmp[2];
     long numrcv;
 
-    *((*this).tmpString) = "";
-    (*((*this).tmpString)).useAsText();
+    (*((*this).tmpString)).useAsBinary(0);
 
     if ((*this).dstSocket < 0 || (*this).bConnected == false) {
         (*this).nErrno = -1;
@@ -608,6 +606,8 @@ String& Socket::receiveLine() {
         return *((*this).tmpString);
     }
 
+    (*((*this).tmpString)).setFixedLength(1024);
+
     (*this).nErrno = 0;
 
     tmp[0] = '\0';
@@ -619,8 +619,8 @@ String& Socket::receiveLine() {
             numrcv = SSL_read((SSL *)((*this).pSSL), tmp, 1);
             if (numrcv == 1) {
                 tmp[1] = '\0';
-                (*((*this).tmpString)) += tmp;
-                if (tmp[0] == '\n') {
+                (*((*this).tmpString)).addBinary(tmp, numrcv);
+                if (tmp[0] == '\n' || tmp[0] == '\0') {
                     break;
                 }
             } else if (numrcv < 0) {
@@ -630,10 +630,7 @@ String& Socket::receiveLine() {
                 usleep(100);
             }
         } while (numrcv != 0);
-        if (tmp[0] != '\n') {
-            (*this).nErrno = -1;
-        }
-        if ((*((*this).tmpString)).len() == 0) {
+        if ((*((*this).tmpString)).binaryLength() == 0) {
             (*this).disconnect();
         }
         return *((*this).tmpString);
@@ -654,8 +651,8 @@ String& Socket::receiveLine() {
                 numrcv = recv((*this).dstSocket, tmp, 1, MSG_WAITALL);
                 if (0 < numrcv) {
                     tmp[1] = '\0';
-                    (*((*this).tmpString)) += tmp;
-                    if (tmp[0] == '\n') {
+                    (*((*this).tmpString)).addBinary(tmp, numrcv);
+                    if (tmp[0] == '\n' || tmp[0] == '\0') {
                         break;
                     }
                 } else if (numrcv < 0) {
@@ -667,10 +664,7 @@ String& Socket::receiveLine() {
             } while (0 < numrcv);
         }
     }
-    if (tmp[0] != '\n') {
-        (*this).nErrno = errno;
-    }
-    if ((*((*this).tmpString)).len() == 0) {
+    if ((*((*this).tmpString)).binaryLength() == 0) {
         (*this).disconnect();
     }
 
