@@ -420,9 +420,9 @@ typedef struct {
 } while(0)
 
 
-#define SBTRANSCMP(a,b)    (TTRANS(transtable,a) == TTRANS(transtable,b))
-#define SBTRANS1CMP(a,c)   (TTRANS(transtable,a) == (c))
-#define SBCMP(a,b)         (ignore_case ? SBTRANSCMP(a,b)  : (a) == (b))
+#define SBTRANSCMP(a,b)    (TTRANS(transtable,(UChar)a) == TTRANS(transtable,(UChar)b))
+#define SBTRANS1CMP(a,c)   (TTRANS(transtable,(UChar)a) == ((UChar)c))
+#define SBCMP(a,b)         (ignore_case ? SBTRANSCMP(a,b)  : ((UChar)a) == ((UChar)b))
 
 #define STRING_CMP(a,b,len) do {\
   if (ignore_case) {\
